@@ -3,7 +3,7 @@ package Firefox::Marionette::Login;
 use strict;
 use warnings;
 
-our $VERSION = '1.67_02';
+our $VERSION = '1.07';
 
 sub _NUMBER_OF_MILLISECONDS_IN_A_SECOND { return 1000 }
 
@@ -131,7 +131,7 @@ Firefox::Marionette::Login - Represents a login from the Firefox Password Manage
 
 =head1 VERSION
 
-Version 1.67_02
+Version 1.05
 
 =head1 SYNOPSIS
 
@@ -243,10 +243,6 @@ returns the HTTP Realm for which the login was requested. When an HTTP server se
 
 returns the number of times the login was submitted in a form or used to begin an HTTP auth session.
 
-=head2 TO_JSON
-
-required to allow L<JSON serialisation|https://metacpan.org/pod/JSON#OBJECT-SERIALISATION> to work correctly.  This method should not need to be called directly.
-
 =head2 user
 
 returns the user name for the login.
@@ -273,7 +269,11 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-To report a bug, or view the current list of bugs, please visit L<https://github.com/david-dick/firefox-marionette/issues>
+No bugs have been reported.
+
+Please report any bugs or feature requests to
+C<bug-firefox-marionette@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
@@ -281,7 +281,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2021, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
